package javax.swing.text;

import java.util.ArrayList;
import java.util.List;

class SegmentCache
{
    private static SegmentCache sharedCache;
    private List<Segment> segments;
    
    public static SegmentCache getSharedInstance() {
        return SegmentCache.sharedCache;
    }
    
    public static Segment getSharedSegment() {
        return getSharedInstance().getSegment();
    }
    
    public static void releaseSharedSegment(Segment segment) {
        getSharedInstance().releaseSegment(segment);
    }
    
    public SegmentCache() {
        this.segments = new ArrayList(11);
    }
    
    public Segment getSegment() {
        synchronized (this) {
            int size = this.segments.size();
            if (size > 0) {
                return (Segment)this.segments.remove(size - 1);
            }
        }
        return new SegmentCache.CachedSegment();
    }
    
    public void releaseSegment(Segment segment) {
        if ((segment instanceof SegmentCache.CachedSegment)) {
            synchronized (this) {
                segment.array = null;
                segment.count = 0;
                this.segments.add(segment);
            }
        }
    }
    
    static {
        SegmentCache.sharedCache = new SegmentCache();
    }
    
    private static class CachedSegment extends Segment
    {
    }
}
